# torchverif
Multiple pytorch tools towards formal verification of neural networks

### Tools

- PyTorch to PVS theory generation
- Interval propagation through PyTorch network
- Statistical Model Checking (SMC) neural network verification

### Prerequisites

Install dependencies with:

```bash
pip install -r requirements.txt
```

### Usage

See `tests/` for examples
